Learn R Programming

tepr (version 1.1.14)

showallcomp: Retrieve all the comparison names from the experiment table

Description

The `showallcomp` function build the string of all comparisons possible using the condition column of a provided experiment table.

Usage

showallcomp(expdf, verbose = FALSE)

Value

If less than three conditions, nothing. Otherwise a character vector of all comparisons.

Arguments

expdf

A data frame containing experiment data that should have columns named 'condition', 'replicate', 'strand', and 'path'.

verbose

A logical flag indicating whether to print progress messages. Defaults to FALSE.

Examples

Run this code
# Create a valid experiment table
exptab <- data.frame(
  condition = c("cond1", "cond2", "cond3"),
  replicate = c(1, 1, 1),
  direction = c("forward", "reverse", "forward"),
  strand = c("plus", "minus", "plus"),
  path = c("toto/", "toto/", "toto/"))
checkexptab(exptab)
showallcomp(exptab)

Run the code above in your browser using DataLab